@@ -6,7 +6,7 @@
 "bagEarth.default" <-
   function(x, y, weights = NULL, B = 50, summary = mean, keepX = TRUE, ...)
 {
-  requireNamespace("earth", quietly = TRUE)
+  requireNamespaceQuietStop("earth")
   funcCall <- match.call(expand.dots = TRUE)
   if(!is.matrix(x)) x <- as.matrix(x)
   if(!is.factor(y))
@@ -30,8 +30,13 @@
     {
       subX <- x[index,, drop = FALSE]
       subY <- y[index]
-      subW <- weights[index]      
-      fit <- earth::earth(subX, subY, subW, ...)
+      
+      if(is.null(w)) {
+        fit <- earth::earth(x = subX, y = subY, ...)
+      } else {
+        subW <- weights[index]  
+        fit <- earth::earth(x = subX, y = subY, weights = subW, ...)
+      }
       fit$index <- index
       fit
     }
@@ -59,12 +64,13 @@
                  summary = summary,
                  call = funcCall,
                  levels = lev,
-                 x = x),
+                 x = x,
+                 weights = !is.null(weights)),
             class = "bagEarth")
 }
 
 "bagEarth.formula" <-
-  function (formula, data = NULL, B = 50, summary = mean, keepX = TRUE, ..., subset, weights, na.action = na.omit) 
+  function (formula, data = NULL, B = 50, summary = mean, keepX = TRUE, ..., subset, weights = NULL, na.action = na.omit) 
 {
   funcCall <- match.call(expand.dots = TRUE)
   
@@ -94,9 +100,9 @@
 "predict.bagEarth" <-
   function(object, newdata = NULL, type = "response", ...)
 {
-  if(!any(type %in% c("response", "class")))
+  if(!any(type %in% c("response", "class", "prob")))
     stop("type must be either response, class or prob")
-  requireNamespace("earth", quietly = TRUE)
+  requireNamespaceQuietStop("earth")
   ## get oob predictions
   getTrainPred <- function(x)
     {
@@ -152,6 +158,7 @@ print.bagEarth <- function (x, ...)
 {
   cat("\nCall:\n", deparse(x$call), "\n\n", sep = "")
   if(!is.null(x$x))cat("Data:\n   # variables:\t", dim(x$x)[2], "\n   # samples:\t", dim(x$x)[1], "\n")
+  if(x$weights) cat("case weights used\n")
   cat("\nB:", x$B,"\n")
   invisible(x)
 }
@@ -159,7 +166,7 @@ print.bagEarth <- function (x, ...)
 "summary.bagEarth" <-
   function(object, ...)
 {
-  requireNamespace("earth", quietly = TRUE)
+  requireNamespaceQuietStop("earth")
   oobStat <- apply(object$oob, 2, function(x) quantile(x, probs = c(0, 0.025, .25, .5, .75, .975, 1)))
 
   numTerms <- unlist(lapply(object$fit, function(x) length(x$selected.terms)))
