@@ -921,8 +921,8 @@ caretGA <- list(fit = function(x, y, lev = NULL, last = FALSE, ...) train(x, y,
                 selectIter = best)
 
 treebagGA <- list(fit = function(x, y, lev = NULL, last = FALSE, ...) {
-  library(ipred)
-  ipredbagg(y, x, ...)
+  loadNamespace("ipred")
+  ipred::ipredbagg(y, x, ...)
 },
 pred = function(object, x) {
   tmp <- predict(object, x)
@@ -942,8 +942,8 @@ mutation = gafs_raMutation,
 selectIter = best)
 
 rfGA <-  list(fit = function(x, y, lev = NULL, last = FALSE, ...) {
-  library(randomForest)
-  randomForest(x, y, ...)
+  loadNamespace("randomForest")
+  randomForest::randomForest(x, y, ...)
 },
 pred = function(object, x) {
   tmp <- predict(object, x)
