@@ -9,7 +9,7 @@ make_noise <- function(n, noiseVars = 0,
     colnames(tmpData) <- well_numbered("Noise", noiseVars)
   }
   if(corrVars > 0) {
-    library(MASS)
+    loadNamespace("MASS")
     if(corrType == "exch") {
       vc <- matrix(corrValue, ncol = corrVars,  nrow = corrVars)
       diag(vc) <- 1
@@ -74,7 +74,7 @@ SLC14_2 <- function(n = 100, noiseVars = 0,
 
 
 LPH07_1 <- function(n = 100, noiseVars = 0, 
-                    corrVars = 0, corrType = "AR1", corrValue = 0) {
+                    corrVars = 0, corrType = "AR1", corrValue = 0, factors = FALSE, class = FALSE) {
   
   dat <- matrix(rbinom(n*10, size = 1, prob = .4), ncol = 10)
   dat <- as.data.frame(dat)
@@ -90,8 +90,19 @@ LPH07_1 <- function(n = 100, noiseVars = 0,
                                  corrType = corrType, 
                                  corrValue = corrValue,
                                  binary = TRUE))
+
+  if(class) {   
+    dat$y <- apply(dat[, 1:10], 1, foo) 
+    dat$Class <- runif(nrow(dat)) <= binomial()$linkinv(dat$y)
+    dat$Class <- factor(ifelse(dat$Class, "Class1", "Class2"))
+    dat$y <- NULL
+  } else dat$y <- apply(dat[, 1:10], 1, foo) + rnorm(n)
+  
+  if(factors) 
+    for(i in grep("(^Var)|(^Noise)", names(dat), value = TRUE))
+      dat[,i] <- factor(paste0("val", dat[,i]))
+  
   
-  dat$y <- apply(dat[, 1:10], 1, foo) + rnorm(n)
   dat
 }
 
