@@ -66,263 +66,267 @@ nominalTrainWorkflow <- function(x, y, wts, info, method, ppOpts, ctrl, lev, tes
   
   result <- foreach(iter = seq(along = resampleIndex), .combine = "c", .verbose = FALSE, .packages = pkgs, .errorhandling = "stop") %:%
     foreach(parm = 1:nrow(info$loop), .combine = "c", .verbose = FALSE, .packages = pkgs, .errorhandling = "stop")  %op%
-{
-  testing <- FALSE
-  if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[[iter]][parm])
-  
-  loadNamespace("caret")
-  if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE],
-                                names(resampleIndex), iter)
-  
-  if(names(resampleIndex)[iter] != "AllData")
-  {
-    modelIndex <- resampleIndex[[iter]]
-    holdoutIndex <- ctrl$indexOut[[iter]]
-  } else {
-    modelIndex <- 1:nrow(x)
-    holdoutIndex <- modelIndex
-  }
-  
-  if(testing) cat("pre-model\n")
-  
-  if(is.null(info$submodels[[parm]]) || nrow(info$submodels[[parm]]) > 0) {
-    submod <- info$submodels[[parm]]
-  } else submod <- NULL
-  
-  mod <- try(
-    createModel(x = x[modelIndex,,drop = FALSE ],
-                y = y[modelIndex],
-                wts = wts[modelIndex],
-                method = method,
-                tuneValue = info$loop[parm,,drop = FALSE],
-                obsLevels = lev,
-                pp = ppp,
-                classProbs = ctrl$classProbs,
-                sampling = ctrl$sampling,
-                ...),
-    silent = TRUE)
-  
-  if(class(mod)[1] != "try-error")
-  {
-    predicted <- try(
-      predictionFunction(method = method,
-                         modelFit = mod$fit,
-                         newdata = x[holdoutIndex,, drop = FALSE],
-                         preProc = mod$preProc,
-                         param = submod),
-      silent = TRUE)
-    
-    if(class(predicted)[1] == "try-error")
     {
-      wrn <- paste(colnames(printed[parm,,drop = FALSE]),
-                   printed[parm,,drop = FALSE],
-                   sep = "=",
-                   collapse = ", ")
-      wrn <- paste("predictions failed for ", names(resampleIndex)[iter],
-                   ": ", wrn, " ", as.character(predicted), sep = "")
-      if(ctrl$verboseIter) cat(wrn, "\n")
-      warning(wrn)
-      rm(wrn)
+      testing <- FALSE
+      if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[[iter]][parm])
       
-      ## setup a dummy results with NA values for all predictions
-      nPred <- length(holdoutIndex)
-      if(!is.null(lev))
+      loadNamespace("caret")
+      if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE],
+                                    names(resampleIndex), iter)
+      
+      if(names(resampleIndex)[iter] != "AllData")
       {
-        predicted <- rep("", nPred)
-        predicted[seq(along = predicted)] <- NA
+        modelIndex <- resampleIndex[[iter]]
+        holdoutIndex <- ctrl$indexOut[[iter]]
       } else {
-        predicted <- rep(NA, nPred)
+        modelIndex <- 1:nrow(x)
+        holdoutIndex <- modelIndex
       }
-      if(!is.null(submod))
+      
+      if(testing) cat("pre-model\n")
+
+      if(!is.null(info$submodels[[parm]]) && nrow(info$submodels[[parm]]) > 0) {
+        submod <- info$submodels[[parm]]
+      } else submod <- NULL
+      
+      mod <- try(
+        createModel(x = x[modelIndex,,drop = FALSE ],
+                    y = y[modelIndex],
+                    wts = wts[modelIndex],
+                    method = method,
+                    tuneValue = info$loop[parm,,drop = FALSE],
+                    obsLevels = lev,
+                    pp = ppp,
+                    classProbs = ctrl$classProbs,
+                    sampling = ctrl$sampling,
+                    ...),
+        silent = TRUE)
+      
+      if(testing) print(mod) 
+      
+      if(class(mod)[1] != "try-error")
       {
-        tmp <- predicted
-        predicted <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
-        for(i in seq(along = predicted)) predicted[[i]] <- tmp
-        rm(tmp)
-      }
-    }
-  } else {
-    wrn <- paste(colnames(printed[parm,,drop = FALSE]),
-                 printed[parm,,drop = FALSE],
-                 sep = "=",
-                 collapse = ", ")
-    wrn <- paste("model fit failed for ", names(resampleIndex)[iter],
-                 ": ", wrn, " ", as.character(mod), sep = "")
-    if(ctrl$verboseIter) cat(wrn, "\n")
-    warning(wrn)
-    rm(wrn)
-    
-    ## setup a dummy results with NA values for all predictions
-    nPred <- length(holdoutIndex)
-    if(!is.null(lev))
-    {
-      predicted <- rep("", nPred)
-      predicted[seq(along = predicted)] <- NA
-    } else {
-      predicted <- rep(NA, nPred)
-    }
-    if(!is.null(submod))
-    {
-      tmp <- predicted
-      predicted <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
-      for(i in seq(along = predicted)) predicted[[i]] <- tmp
-      rm(tmp)
-    }
-  }
-  
-  if(testing) print(head(predicted))
-  if(ctrl$classProbs)
-  {
-    if(class(mod)[1] != "try-error")
-    {
-      probValues <- probFunction(method = method,
-                                 modelFit = mod$fit,
-                                 newdata = x[holdoutIndex,, drop = FALSE],
-                                 preProc = mod$preProc,
-                                 param = submod)
-    } else {
-      probValues <- as.data.frame(matrix(NA, nrow = nPred, ncol = length(lev)))
-      colnames(probValues) <- lev
-      if(!is.null(submod))
-      {
-        tmp <- probValues
-        probValues <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
-        for(i in seq(along = probValues)) probValues[[i]] <- tmp
-        rm(tmp)
-      }
-    }
-    if(testing) print(head(probValues))
-  }
-  
-  ##################################
-  
-  if(is.numeric(y)) {
-    if(is.logical(ctrl$predictionBounds) && any(ctrl$predictionBounds)) {
-      if(is.list(predicted)) {
-        predicted <- lapply(predicted, trimPredictions,
-                            mod_type = "Regression",
-                            bounds = ctrl$predictionBounds,
-                            limits = ctrl$yLimits)
+        predicted <- try(
+          predictionFunction(method = method,
+                             modelFit = mod$fit,
+                             newdata = x[holdoutIndex,, drop = FALSE],
+                             preProc = mod$preProc,
+                             param = submod),
+          silent = TRUE)
+        
+        if(class(predicted)[1] == "try-error")
+        {
+          wrn <- paste(colnames(printed[parm,,drop = FALSE]),
+                       printed[parm,,drop = FALSE],
+                       sep = "=",
+                       collapse = ", ")
+          wrn <- paste("predictions failed for ", names(resampleIndex)[iter],
+                       ": ", wrn, " ", as.character(predicted), sep = "")
+          if(ctrl$verboseIter) cat(wrn, "\n")
+          warning(wrn)
+          rm(wrn)
+          
+          ## setup a dummy results with NA values for all predictions
+          nPred <- length(holdoutIndex)
+          if(!is.null(lev))
+          {
+            predicted <- rep("", nPred)
+            predicted[seq(along = predicted)] <- NA
+          } else {
+            predicted <- rep(NA, nPred)
+          }
+          if(!is.null(submod))
+          {
+            tmp <- predicted
+            predicted <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
+            for(i in seq(along = predicted)) predicted[[i]] <- tmp
+            rm(tmp)
+          }
+        }
       } else {
-        predicted <- trimPredictions(mod_type = "Regression",
-                                     bounds =  ctrl$predictionBounds,
-                                     limits =  ctrl$yLimit,
-                                     pred = predicted)
-      }
-    } else {
-      if(is.numeric(ctrl$predictionBounds) && any(!is.na(ctrl$predictionBounds))) {
-        if(is.list(predicted)) {
-          predicted <- lapply(predicted, trimPredictions,
-                              mod_type = "Regression",
-                              bounds = ctrl$predictionBounds,
-                              limits = ctrl$yLimits)
+        wrn <- paste(colnames(printed[parm,,drop = FALSE]),
+                     printed[parm,,drop = FALSE],
+                     sep = "=",
+                     collapse = ", ")
+        wrn <- paste("model fit failed for ", names(resampleIndex)[iter],
+                     ": ", wrn, " ", as.character(mod), sep = "")
+        if(ctrl$verboseIter) cat(wrn, "\n")
+        warning(wrn)
+        rm(wrn)
+        
+        ## setup a dummy results with NA values for all predictions
+        nPred <- length(holdoutIndex)
+        if(!is.null(lev))
+        {
+          predicted <- rep("", nPred)
+          predicted[seq(along = predicted)] <- NA
         } else {
-          predicted <- trimPredictions(mod_type = "Regression",
-                                       bounds =  ctrl$predictionBounds,
-                                       limits =  ctrl$yLimit,
-                                       pred = predicted)
+          predicted <- rep(NA, nPred)
+        }
+        if(!is.null(submod))
+        {
+          tmp <- predicted
+          predicted <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
+          for(i in seq(along = predicted)) predicted[[i]] <- tmp
+          rm(tmp)
         }
       }
-    } 
-  }
-  
-  if(!is.null(submod))
-  {
-    ## merge the fixed and seq parameter values together
-    allParam <- expandParameters(info$loop[parm,,drop = FALSE], info$submodels[[parm]])
-    allParam <- allParam[complete.cases(allParam),, drop = FALSE]
-    
-    ## collate the predicitons across all the sub-models
-    predicted <- lapply(predicted,
-                        function(x, y, wts, lv, rows) {
-                          x <- outcome_conversion(x, lv = lev)
-                          out <- data.frame(pred = x, obs = y, stringsAsFactors = FALSE)
-                          if(!is.null(wts)) out$weights <- wts
-                          out$rowIndex <- rows
-                          out
-                        },
-                        y = y[holdoutIndex],
-                        wts = wts[holdoutIndex],
-                        lv = lev,
-                        rows = holdoutIndex)
-    if(testing) print(head(predicted))
-
-    ## same for the class probabilities
-    if(ctrl$classProbs)
-    {
-      for(k in seq(along = predicted)) predicted[[k]] <- cbind(predicted[[k]], probValues[[k]])
-    }
-    
-    if(keep_pred)
-    {
-      tmpPred <- predicted
-      for(modIndex in seq(along = tmpPred))
+      
+      if(testing) print(head(predicted))
+      if(ctrl$classProbs)
       {
-        tmpPred[[modIndex]]$rowIndex <- holdoutIndex
-        tmpPred[[modIndex]] <- merge(tmpPred[[modIndex]], 
-                                     allParam[modIndex,,drop = FALSE],
-                                     all = TRUE)
+        if(class(mod)[1] != "try-error")
+        {
+          probValues <- probFunction(method = method,
+                                     modelFit = mod$fit,
+                                     newdata = x[holdoutIndex,, drop = FALSE],
+                                     preProc = mod$preProc,
+                                     param = submod)
+        } else {
+          probValues <- as.data.frame(matrix(NA, nrow = nPred, ncol = length(lev)))
+          colnames(probValues) <- lev
+          if(!is.null(submod))
+          {
+            tmp <- probValues
+            probValues <- vector(mode = "list", length = nrow(info$submodels[[parm]]) + 1)
+            for(i in seq(along = probValues)) probValues[[i]] <- tmp
+            rm(tmp)
+          }
+        }
+        if(testing) print(head(probValues))
       }
-      tmpPred <- rbind.fill(tmpPred)
-      tmpPred$Resample <- names(resampleIndex)[iter]
-    } else tmpPred <- NULL
-    
-    ## get the performance for this resample for each sub-model
-    thisResample <- lapply(predicted,
-                           ctrl$summaryFunction,
-                           lev = lev,
-                           model = method)
-    if(testing) print(head(thisResample))
-    ## for classification, add the cell counts
-    if(length(lev) > 1 && length(lev) <= 50)
-    {
-      cells <- lapply(predicted,
-                      function(x) flatTable(x$pred, x$obs))
-      for(ind in seq(along = cells)) thisResample[[ind]] <- c(thisResample[[ind]], cells[[ind]])
+      
+      ##################################
+      
+      if(is.numeric(y)) {
+        if(is.logical(ctrl$predictionBounds) && any(ctrl$predictionBounds)) {
+          if(is.list(predicted)) {
+            predicted <- lapply(predicted, trimPredictions,
+                                mod_type = "Regression",
+                                bounds = ctrl$predictionBounds,
+                                limits = ctrl$yLimits)
+          } else {
+            predicted <- trimPredictions(mod_type = "Regression",
+                                         bounds =  ctrl$predictionBounds,
+                                         limits =  ctrl$yLimit,
+                                         pred = predicted)
+          }
+        } else {
+          if(is.numeric(ctrl$predictionBounds) && any(!is.na(ctrl$predictionBounds))) {
+            if(is.list(predicted)) {
+              predicted <- lapply(predicted, trimPredictions,
+                                  mod_type = "Regression",
+                                  bounds = ctrl$predictionBounds,
+                                  limits = ctrl$yLimits)
+            } else {
+              predicted <- trimPredictions(mod_type = "Regression",
+                                           bounds =  ctrl$predictionBounds,
+                                           limits =  ctrl$yLimit,
+                                           pred = predicted)
+            }
+          }
+        } 
+      }
+      
+      if(!is.null(submod))
+      {
+        ## merge the fixed and seq parameter values together
+        allParam <- expandParameters(info$loop[parm,,drop = FALSE], info$submodels[[parm]])
+        allParam <- allParam[complete.cases(allParam),, drop = FALSE]
+        
+        ## collate the predicitons across all the sub-models
+        predicted <- lapply(predicted,
+                            function(x, y, wts, lv, rows) {
+                              x <- outcome_conversion(x, lv = lev)
+                              out <- data.frame(pred = x, obs = y, stringsAsFactors = FALSE)
+                              if(!is.null(wts)) out$weights <- wts
+                              out$rowIndex <- rows
+                              out
+                            },
+                            y = y[holdoutIndex],
+                            wts = wts[holdoutIndex],
+                            lv = lev,
+                            rows = holdoutIndex)
+        if(testing) print(head(predicted))
+        
+        ## same for the class probabilities
+        if(ctrl$classProbs)
+        {
+          for(k in seq(along = predicted)) predicted[[k]] <- cbind(predicted[[k]], probValues[[k]])
+        }
+        
+        if(keep_pred)
+        {
+          tmpPred <- predicted
+          for(modIndex in seq(along = tmpPred))
+          {
+            tmpPred[[modIndex]]$rowIndex <- holdoutIndex
+            tmpPred[[modIndex]] <- merge(tmpPred[[modIndex]], 
+                                         allParam[modIndex,,drop = FALSE],
+                                         all = TRUE)
+          }
+          tmpPred <- rbind.fill(tmpPred)
+          tmpPred$Resample <- names(resampleIndex)[iter]
+        } else tmpPred <- NULL
+        
+        ## get the performance for this resample for each sub-model
+        thisResample <- lapply(predicted,
+                               ctrl$summaryFunction,
+                               lev = lev,
+                               model = method)
+        if(testing) print(head(thisResample))
+        ## for classification, add the cell counts
+        if(length(lev) > 1 && length(lev) <= 50)
+        {
+          cells <- lapply(predicted,
+                          function(x) flatTable(x$pred, x$obs))
+          for(ind in seq(along = cells)) thisResample[[ind]] <- c(thisResample[[ind]], cells[[ind]])
+        }
+        thisResample <- do.call("rbind", thisResample)          
+        thisResample <- cbind(allParam, thisResample)
+        
+      } else {       
+        if(is.factor(y)) predicted <- outcome_conversion(predicted, lv = lev)
+        tmp <-  data.frame(pred = predicted,
+                           obs = y[holdoutIndex],
+                           stringsAsFactors = FALSE)
+        ## Sometimes the code above does not coerce the first
+        ## columnn to be named "pred" so force it
+        names(tmp)[1] <- "pred"
+        if(!is.null(wts)) tmp$weights <- wts[holdoutIndex]
+        if(ctrl$classProbs) tmp <- cbind(tmp, probValues)
+        tmp$rowIndex <- holdoutIndex
+        
+        if(keep_pred)
+        {
+          tmpPred <- tmp
+          tmpPred$rowIndex <- holdoutIndex
+          tmpPred <- merge(tmpPred, info$loop[parm,,drop = FALSE],
+                           all = TRUE)
+          tmpPred$Resample <- names(resampleIndex)[iter]
+        } else tmpPred <- NULL
+        
+        ##################################
+        
+        thisResample <- ctrl$summaryFunction(tmp,
+                                             lev = lev,
+                                             model = method)
+        
+        ## if classification, get the confusion matrix
+        if(length(lev) > 1 && length(lev) <= 50) thisResample <- c(thisResample, flatTable(tmp$pred, tmp$obs))
+        thisResample <- as.data.frame(t(thisResample))
+        thisResample <- cbind(thisResample, info$loop[parm,,drop = FALSE])
+        
+      }
+      thisResample$Resample <- names(resampleIndex)[iter]
+      
+      if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE],
+                                    names(resampleIndex), iter, FALSE)
+      
+      if(testing) print(thisResample)
+      list(resamples = thisResample, pred = tmpPred)
     }
-    thisResample <- do.call("rbind", thisResample)          
-    thisResample <- cbind(allParam, thisResample)
-    
-  } else {       
-    if(is.factor(y)) predicted <- outcome_conversion(predicted, lv = lev)
-    tmp <-  data.frame(pred = predicted,
-                       obs = y[holdoutIndex],
-                       stringsAsFactors = FALSE)
-    ## Sometimes the code above does not coerce the first
-    ## columnn to be named "pred" so force it
-    names(tmp)[1] <- "pred"
-    if(!is.null(wts)) tmp$weights <- wts[holdoutIndex]
-    if(ctrl$classProbs) tmp <- cbind(tmp, probValues)
-    tmp$rowIndex <- holdoutIndex
-    
-    if(keep_pred)
-    {
-      tmpPred <- tmp
-      tmpPred$rowIndex <- holdoutIndex
-      tmpPred <- merge(tmpPred, info$loop[parm,,drop = FALSE],
-                       all = TRUE)
-      tmpPred$Resample <- names(resampleIndex)[iter]
-    } else tmpPred <- NULL
-
-    ##################################
-    
-    thisResample <- ctrl$summaryFunction(tmp,
-                                         lev = lev,
-                                         model = method)
-    
-    ## if classification, get the confusion matrix
-    if(length(lev) > 1 && length(lev) <= 50) thisResample <- c(thisResample, flatTable(tmp$pred, tmp$obs))
-    thisResample <- as.data.frame(t(thisResample))
-    thisResample <- cbind(thisResample, info$loop[parm,,drop = FALSE])
-    
-  }
-  thisResample$Resample <- names(resampleIndex)[iter]
   
-  if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE],
-                                names(resampleIndex), iter, FALSE)
-  list(resamples = thisResample, pred = tmpPred)
-}
-
   resamples <- rbind.fill(result[names(result) == "resamples"])
   pred <- if(keep_pred)  rbind.fill(result[names(result) == "pred"]) else NULL
   if(ctrl$method %in% c("boot632"))
@@ -353,7 +357,7 @@ nominalTrainWorkflow <- function(x, y, wts, info, method, ppOpts, ctrl, lev, tes
                gsub("^\\.", "", colnames(info$loop)),
                MeanSD, 
                exclude = gsub("^\\.", "", colnames(info$loop)))
-
+  
   if(ctrl$method %in% c("boot632")) {
     out <- merge(out, apparent)
     for(p in seq(along = perfNames)) {
@@ -519,29 +523,29 @@ oobTrainWorkflow <- function(x, y, wts, info, method, ppOpts, ctrl, lev, testing
   pkgs <- c("methods", "caret")
   if(!is.null(method$library)) pkgs <- c(pkgs, method$library)
   result <- foreach(parm = 1:nrow(info$loop), .packages = pkgs, .combine = "rbind") %op%
-{
-  loadNamespace("caret")
-  if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE], "", 1, TRUE)
-  
-  if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[[1L]][parm])
-  
-  mod <- createModel(x = x,
-                     y = y,
-                     wts = wts,
-                     method = method,
-                     tuneValue = info$loop[parm,,drop = FALSE],
-                     obsLevels = lev,
-                     pp = ppp,
-                     classProbs = ctrl$classProbs,
-                     sampling = ctrl$sampling,
-                     ...)
-  
-  out <- method$oob(mod$fit)
-  
-  if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE], "", 1, FALSE)
-  
-  cbind(as.data.frame(t(out)), info$loop[parm,,drop = FALSE])
-}
+  {
+    loadNamespace("caret")
+    if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE], "", 1, TRUE)
+    
+    if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[[1L]][parm])
+    
+    mod <- createModel(x = x,
+                       y = y,
+                       wts = wts,
+                       method = method,
+                       tuneValue = info$loop[parm,,drop = FALSE],
+                       obsLevels = lev,
+                       pp = ppp,
+                       classProbs = ctrl$classProbs,
+                       sampling = ctrl$sampling,
+                       ...)
+    
+    out <- method$oob(mod$fit)
+    
+    if(ctrl$verboseIter) progress(printed[parm,,drop = FALSE], "", 1, FALSE)
+    
+    cbind(as.data.frame(t(out)), info$loop[parm,,drop = FALSE])
+  }
   names(result) <- gsub("^\\.", "", names(result))
   result
 }
@@ -562,38 +566,38 @@ nominalSbfWorkflow <- function(x, y, ppOpts, ctrl, lev, ...)
   
   `%op%` <- getOper(ctrl$allowParallel && getDoParWorkers() > 1)
   result <- foreach(iter = seq(along = resampleIndex), .combine = "c", .verbose = FALSE, .packages = c("methods", "caret"), .errorhandling = "stop") %op%
-{
-  if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[iter])
-  
-  loadNamespace("caret")
-  
-  if(names(resampleIndex)[iter] != "AllData") {
-    modelIndex <- resampleIndex[[iter]]
-    holdoutIndex <- ctrl$indexOut[[iter]]
-  } else {
-    modelIndex <- 1:nrow(x)
-    holdoutIndex <- modelIndex
-  }
-  
-  sbfResults <- sbfIter(x[modelIndex,,drop = FALSE],
-                        y[modelIndex],
-                        x[holdoutIndex,,drop = FALSE],
-                        y[holdoutIndex],
-                        ctrl,
-                        ...)
-  if(ctrl$saveDetails)
   {
-    tmpPred <- sbfResults$pred
-    tmpPred$Resample <- names(resampleIndex)[iter]
-    tmpPred$rowIndex <- seq(along = y)[unique(holdoutIndex)]
-  } else tmpPred <- NULL
-  resamples <- ctrl$functions$summary(sbfResults$pred, lev = lev)
-  if(is.factor(y) && length(lev) <= 50) resamples <- c(resamples, flatTable(sbfResults$pred$pred, sbfResults$pred$obs))
-  resamples <- data.frame(t(resamples))
-  resamples$Resample <- names(resampleIndex)[iter]
-  
-  list(resamples = resamples, selectedVars = sbfResults$variables, pred = tmpPred)
-}
+    if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[iter])
+    
+    loadNamespace("caret")
+    
+    if(names(resampleIndex)[iter] != "AllData") {
+      modelIndex <- resampleIndex[[iter]]
+      holdoutIndex <- ctrl$indexOut[[iter]]
+    } else {
+      modelIndex <- 1:nrow(x)
+      holdoutIndex <- modelIndex
+    }
+    
+    sbfResults <- sbfIter(x[modelIndex,,drop = FALSE],
+                          y[modelIndex],
+                          x[holdoutIndex,,drop = FALSE],
+                          y[holdoutIndex],
+                          ctrl,
+                          ...)
+    if(ctrl$saveDetails)
+    {
+      tmpPred <- sbfResults$pred
+      tmpPred$Resample <- names(resampleIndex)[iter]
+      tmpPred$rowIndex <- seq(along = y)[unique(holdoutIndex)]
+    } else tmpPred <- NULL
+    resamples <- ctrl$functions$summary(sbfResults$pred, lev = lev)
+    if(is.factor(y) && length(lev) <= 50) resamples <- c(resamples, flatTable(sbfResults$pred$pred, sbfResults$pred$obs))
+    resamples <- data.frame(t(resamples))
+    resamples$Resample <- names(resampleIndex)[iter]
+    
+    list(resamples = resamples, selectedVars = sbfResults$variables, pred = tmpPred)
+  }
   
   resamples <- rbind.fill(result[names(result) == "resamples"])
   pred <- if(ctrl$saveDetails) rbind.fill(result[names(result) == "pred"]) else NULL
@@ -636,23 +640,23 @@ looSbfWorkflow <- function(x, y, ppOpts, ctrl, lev, ...)
   
   `%op%` <- getOper(ctrl$allowParallel && getDoParWorkers() > 1)
   result <- foreach(iter = seq(along = resampleIndex), .combine = "c", .verbose = FALSE, .packages = c("methods", "caret"), .errorhandling = "stop") %op%
-{
-  if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[iter])
-  
-  loadNamespace("caret")
-  
-  modelIndex <- resampleIndex[[iter]]
-  holdoutIndex <- -unique(resampleIndex[[iter]])
-  
-  sbfResults <- sbfIter(x[modelIndex,,drop = FALSE],
-                        y[modelIndex],
-                        x[holdoutIndex,,drop = FALSE],
-                        y[holdoutIndex],
-                        ctrl,
-                        ...)
-  
-  sbfResults
-}
+  {
+    if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) set.seed(ctrl$seeds[iter])
+    
+    loadNamespace("caret")
+    
+    modelIndex <- resampleIndex[[iter]]
+    holdoutIndex <- -unique(resampleIndex[[iter]])
+    
+    sbfResults <- sbfIter(x[modelIndex,,drop = FALSE],
+                          y[modelIndex],
+                          x[holdoutIndex,,drop = FALSE],
+                          y[holdoutIndex],
+                          ctrl,
+                          ...)
+    
+    sbfResults
+  }
   resamples <- do.call("rbind", result[names(result) == "pred"])
   performance <- ctrl$functions$summary(resamples, lev = lev)
   
@@ -676,48 +680,48 @@ nominalRfeWorkflow <- function(x, y, sizes, ppOpts, ctrl, lev, ...)
   
   `%op%` <- getOper(ctrl$allowParallel && getDoParWorkers() > 1)
   result <- foreach(iter = seq(along = resampleIndex), .combine = "c", .verbose = FALSE, .packages = c("methods", "caret", "plyr"), .errorhandling = "stop") %op%
-{
-  loadNamespace("caret")
-  
-  if(names(resampleIndex)[iter] != "AllData") {
-    modelIndex <- resampleIndex[[iter]]
-    holdoutIndex <- ctrl$indexOut[[iter]]
-  } else {
-    modelIndex <- 1:nrow(x)
-    holdoutIndex <- modelIndex
-  }
-  
-  seeds <- if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) ctrl$seeds[[iter]] else NA
-  rfeResults <- rfeIter(x[modelIndex,,drop = FALSE],
-                        y[modelIndex],
-                        x[holdoutIndex,,drop = FALSE],
-                        y[holdoutIndex],
-                        sizes,
-                        ctrl,
-                        label = names(resampleIndex)[iter],
-                        seeds = seeds,
-                        ...)
-  resamples <- ddply(rfeResults$pred, .(Variables), ctrl$functions$summary, lev = lev)
-  
-  if(ctrl$saveDetails)
   {
-    rfeResults$pred$Resample <- names(resampleIndex)[iter]
-    ## If the user did not have nrow(x) in 'sizes', rfeIter added it.
-    ## So, we need to find out how many set of predictions there are:
-    nReps <- length(table(rfeResults$pred$Variables))
-    rfeResults$pred$rowIndex <- rep(seq(along = y)[unique(holdoutIndex)], nReps)
+    loadNamespace("caret")
+    
+    if(names(resampleIndex)[iter] != "AllData") {
+      modelIndex <- resampleIndex[[iter]]
+      holdoutIndex <- ctrl$indexOut[[iter]]
+    } else {
+      modelIndex <- 1:nrow(x)
+      holdoutIndex <- modelIndex
+    }
+    
+    seeds <- if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) ctrl$seeds[[iter]] else NA
+    rfeResults <- rfeIter(x[modelIndex,,drop = FALSE],
+                          y[modelIndex],
+                          x[holdoutIndex,,drop = FALSE],
+                          y[holdoutIndex],
+                          sizes,
+                          ctrl,
+                          label = names(resampleIndex)[iter],
+                          seeds = seeds,
+                          ...)
+    resamples <- ddply(rfeResults$pred, .(Variables), ctrl$functions$summary, lev = lev)
+    
+    if(ctrl$saveDetails)
+    {
+      rfeResults$pred$Resample <- names(resampleIndex)[iter]
+      ## If the user did not have nrow(x) in 'sizes', rfeIter added it.
+      ## So, we need to find out how many set of predictions there are:
+      nReps <- length(table(rfeResults$pred$Variables))
+      rfeResults$pred$rowIndex <- rep(seq(along = y)[unique(holdoutIndex)], nReps)
+    }
+    
+    if(is.factor(y) && length(lev) <= 50) {
+      cells <- ddply(rfeResults$pred, .(Variables), function(x) flatTable(x$pred, x$obs))
+      resamples <- merge(resamples, cells)
+    }
+    
+    resamples$Resample <- names(resampleIndex)[iter]
+    vars <- do.call("rbind", rfeResults$finalVariables)
+    vars$Resample <- names(resampleIndex)[iter]
+    list(resamples = resamples, selectedVars = vars, predictions = if(ctrl$saveDetails) rfeResults$pred else NULL)
   }
-  
-  if(is.factor(y) && length(lev) <= 50) {
-    cells <- ddply(rfeResults$pred, .(Variables), function(x) flatTable(x$pred, x$obs))
-    resamples <- merge(resamples, cells)
-  }
-  
-  resamples$Resample <- names(resampleIndex)[iter]
-  vars <- do.call("rbind", rfeResults$finalVariables)
-  vars$Resample <- names(resampleIndex)[iter]
-  list(resamples = resamples, selectedVars = vars, predictions = if(ctrl$saveDetails) rfeResults$pred else NULL)
-}
   resamples <- do.call("rbind", result[names(result) == "resamples"])
   rownames(resamples) <- NULL
   
@@ -761,23 +765,23 @@ looRfeWorkflow <- function(x, y, sizes, ppOpts, ctrl, lev, ...)
   resampleIndex <- ctrl$index
   `%op%` <- getOper(ctrl$allowParallel && getDoParWorkers() > 1)
   result <- foreach(iter = seq(along = resampleIndex), .combine = "c", .verbose = FALSE, .packages = c("methods", "caret"), .errorhandling = "stop") %op%
-{
-  loadNamespace("caret")
-  
-  modelIndex <- resampleIndex[[iter]]
-  holdoutIndex <- -unique(resampleIndex[[iter]])
-  
-  seeds <- if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) ctrl$seeds[[iter]] else NA
-  rfeResults <- rfeIter(x[modelIndex,,drop = FALSE],
-                        y[modelIndex],
-                        x[holdoutIndex,,drop = FALSE],
-                        y[holdoutIndex],
-                        sizes,
-                        ctrl,
-                        seeds = seeds,
-                        ...)
-  rfeResults
-}
+  {
+    loadNamespace("caret")
+    
+    modelIndex <- resampleIndex[[iter]]
+    holdoutIndex <- -unique(resampleIndex[[iter]])
+    
+    seeds <- if(!(length(ctrl$seeds) == 1 && is.na(ctrl$seeds))) ctrl$seeds[[iter]] else NA
+    rfeResults <- rfeIter(x[modelIndex,,drop = FALSE],
+                          y[modelIndex],
+                          x[holdoutIndex,,drop = FALSE],
+                          y[holdoutIndex],
+                          sizes,
+                          ctrl,
+                          seeds = seeds,
+                          ...)
+    rfeResults
+  }
   preds <- do.call("rbind", result[names(result) == "pred"])
   resamples <- ddply(preds, .(Variables), ctrl$functions$summary, lev = lev)   
   list(performance = resamples, everything = result)
